@@ -12,8 +12,6 @@ from graphsignal.uploader import Uploader
 
 logger = logging.getLogger('graphsignal')
 
-UPLOAD_INTERVAL = 120
-
 _config = None
 _uploader = None
 
@@ -21,8 +19,9 @@ _uploader = None
 class Config(object):
     def __init__(self):
         self.api_key = None
-        self.debug_mode = False
-        self.log_system_metrics = True
+        self.debug_mode = None
+        self.window_seconds = None
+        self.buffer_size = None
 
 
 def _get_config():
@@ -33,19 +32,7 @@ def _get_uploader():
     return _uploader
 
 
-def configure(api_key, debug_mode=False, log_system_metrics=True):
-    '''
-    Configures and initializes the logger.
-
-    Args:
-        api_key (:obj:`str`):
-            The access key for communication with the Graphsignal servers.
-        debug_mode (:obj:`bool`, optional):
-            Enable/disable debug output.
-        log_system_metrics (:obj:`bool`, optional, default is ``True``):
-            Enable/disable the recording and uploading of system metrics.
-    '''
-
+def configure(api_key, debug_mode=False, window_seconds=300, buffer_size=100):
     global _config, _uploader
 
     if _config:
@@ -64,7 +51,8 @@ def configure(api_key, debug_mode=False, log_system_metrics=True):
     _config = Config()
     _config.api_key = api_key
     _config.debug_mode = debug_mode
-    _config.log_system_metrics = log_system_metrics
+    _config.window_seconds = window_seconds
+    _config.buffer_size = buffer_size
 
     _uploader = Uploader()
     _uploader.configure()
@@ -76,14 +64,27 @@ def configure(api_key, debug_mode=False, log_system_metrics=True):
     logger.debug('Logger configured')
 
 
+def tick():
+    if not _config:
+        logger.error(
+            'Logger not configured, please use graphsignal.configure()')
+        return
+
+    sessions.upload_all()
+    _uploader.flush()
+
+
+def flush():
+    if not _config:
+        logger.error(
+            'Logger not configured, please use graphsignal.configure()')
+        return
+
+    sessions.upload_all(force=True)
+    _uploader.flush()
+
+
 def shutdown():
-    '''
-    Send any collected data to the server and cleanup.
-
-    Normally, when python scripts exists, this method is automatically called. Use this method,
-    if you want to explicitely shutdown the logger.
-    '''
-
     global _config
 
     if not _config:
@@ -101,34 +102,7 @@ def shutdown():
     logger.debug('Logger shutdown')
 
 
-def tick():
-    '''
-    Check if any data can be uploaded and if yes, upload.
-    Can be used in situations when logging is irregular and/or rare.
-    '''
-
-    if not _config:
-        logger.error(
-            'Logger not configured, please use graphsignal.configure()')
-        return
-
-    sessions.upload_all()
-    _uploader.flush()
-
-
 def session(deployment_name):
-    '''
-    Get logging session for the model identified by model deployment name.
-
-    Args:
-        deployment_name (:obj:`str`, optional):
-            Model deployment name, e.g. `model1_production`, `modelB_canary` or any other string value.
-    Returns:
-        :obj:`Session` - session object for logging prediction data, metrics and events.
-    Raises:
-        `ValueError`: When `deployment_name` is invalid.
-    '''
-
     if not _config:
         raise ValueError(
             'graphsignal not configured, please use graphsignal.configure()')
