@@ -1,5 +1,6 @@
 import unittest
 import logging
+import sys
 from unittest.mock import patch, Mock
 
 import graphsignal
@@ -9,6 +10,8 @@ logger = logging.getLogger('graphsignal')
 
 class GraphsignalTest(unittest.TestCase):
     def setUp(self):
+        if len(logger.handlers) == 0:
+            logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(api_key='k1', debug_mode=True)
 
     def tearDown(self):
